@@ -103,6 +103,7 @@ public:
 	const char *chkJoin(Line *line, ScriptImage *img);
 	const char *chkDial(Line *line, ScriptImage *img);
 	const char *chkEndinput(Line *line, ScriptImage *img);
+	const char *chkReconnect(Line *line, ScriptImage *img);
 };
 
 class Methods : public BayonneSession
@@ -116,6 +117,7 @@ public:
 	bool scrForm(void);
 	bool scrEndform(void);
 	bool scrEndinput(void);
+	bool scrReconnect(void);
 };
 
 } // namespace
