@@ -200,6 +200,7 @@ public:
 		STATE_JOIN,
 		STATE_WAIT,
 		STATE_CONNECT,
+		STATE_RECONNECT,
 		STATE_HUNTING,
 		STATE_SLEEP,
 		STATE_START,
@@ -291,6 +292,8 @@ public:
 		ERROR_STATE,		// generic enter with error
 		ENTER_HUNTING,
 		EXIT_HUNTING,
+		ENTER_RECONNECT,
+		EXIT_RECONNECT,
 
 		// primary session control events
 
@@ -460,6 +463,8 @@ public:
 		RELOCATE_ACCEPT,	// hunting reply
 		RELOCATE_REJECT,	// a kind of disconnect
 		START_RELOCATE,		// start timeslot for relocation
+		STREAM_ACTIVE,
+		STREAM_PASSIVE,
 
 		// master control events
 
@@ -584,6 +589,12 @@ public:
 				const char *logstate;
 			}	debug;
 
+			struct
+			{
+				const char *encoding;
+				timeout_t framing;
+			}	reconnect;
+
 			const char *name;
 			const char *errmsg;
 			BayonneSession *pid;
@@ -2073,6 +2084,7 @@ protected:
 	virtual bool enterHunting(Event *event);
 	virtual bool enterHangup(Event *event);
 	virtual bool enterTone(Event *event);
+	virtual bool enterReconnect(Event *event);
 	virtual bool enterDTMF(Event *event);
 	virtual bool enterPlay(Event *event);
 	virtual bool enterRecord(Event *event);
@@ -2129,6 +2141,7 @@ protected:
 	bool stateJoin(Event *event);
 	bool stateWait(Event *event);
 	bool stateConnect(Event *event);
+	bool stateReconnect(Event *event);
 
 	/**
 	 * Direct method to post an event to a channel.
@@ -2249,6 +2262,14 @@ protected:
 	 */
 	void setRunning(void);
 
+	/**
+	 * Attempt to readjust encoding of active session if supported.
+	 *
+	 * @param encoding to try
+	 * @param timeout to use
+	 */
+	bool setReconnect(const char *enc, timeout_t framing);
+
 	/**
 	 * Set the session to the connecting (join) state or run state
 	 * based on flags and circumstances from seize/pickup.
