@@ -899,6 +899,38 @@ bool BayonneSession::stateDTMF(Event *event)
 	return stateTone(event);
 }
 
+bool BayonneSession::stateReconnect(Event *event)
+{
+	bool rtn = false;
+	Event ex;
+
+	if(enterReconnect(event))
+		return true;
+
+	switch(event->id)
+	{
+	case ENTER_RECONNECT:
+		return false;
+	case ENTER_STATE:
+		if(state.timeout && state.timeout != TIMEOUT_INF)
+			startTimer(state.timeout);
+		return true;
+	case TIMER_EXPIRED:
+		setRunning();
+		goto finish;
+	default:
+		rtn = enterCommon(event);
+		if(state.handler != &BayonneSession::stateReconnect)
+		{
+finish:
+			memset(&ex, 0, sizeof(event));
+			ex.id = EXIT_RECONNECT;
+			enterReconnect(&ex);
+		}
+		return rtn;
+	}
+}
+
 bool BayonneSession::stateConnect(Event *event)
 {
 	Event cancel;
@@ -2493,6 +2525,11 @@ bool BayonneSession::enterPickup(Event *event)
 	return false;
 }
  
+bool BayonneSession::enterReconnect(Event *event)
+{
+	return false;
+}
+
 bool BayonneSession::enterTone(Event *event)
 {
         return false;
