@@ -263,6 +263,14 @@ Assoc()
 
 	memset(&info, 0, sizeof(info));
 	cp = getLast("encoding");
+	if(!stricmp(cp, "a32"))
+		cp = "adpcm";
+	else if(!stricmp(cp, "a40"))
+		cp = ".a40";
+	else if(!stricmp(cp, "a24"))
+		cp = ".a24";
+	else if(!stricmp(cp, "a16"))
+		cp = ".a16";
 	info.encoding = getEncoding(cp);
 	info.rate = rate8khz;
 	cp = getLast("rate");
