@@ -325,8 +325,9 @@ public:
 	const char *audioExtension(void);
 	const char *checkAudio(bool live);
 
-        uint8 sdpPayload();
-        const char *sdpEncoding();
+        uint8 sdpPayload(void);
+        const char *sdpEncoding(void);
+	const char *sdpNames(void);
 	void setPeering(const char *reg);
 
 	// core timer virtuals all port session objects need to define
