@@ -78,6 +78,35 @@ uint8 Session::sdpPayload(void)
 	}
 }
 
+const char *Session::sdpNames(void)
+{
+	switch(info.encoding)
+	{
+	case Audio::mulawAudio:
+		return "pcmu,mulaw";
+	case Audio::alawAudio:
+		return "pcma,alaw";
+	case Audio::g721ADPCM:
+		return "adpcm,a32,721,726-32";
+	case Audio::g723_2bit:
+		return "a16,726-16";
+	case Audio::g723_3bit:
+		return "a24,726-24";
+	case Audio::g723_5bit:
+		return "a40,726-40";
+	case Audio::g729Audio:
+		return "729";
+	case Audio::pcm16Mono:
+		return "linear,l16";
+	case Audio::pcm16Stereo:
+		return "stereo,l16-2ch";
+	case Audio::gsmVoice:
+		return "gsm";
+	default:
+		return "unknown";
+	}
+}
+
 const char *Session::sdpEncoding(void)
 {
 	switch(info.encoding)
@@ -89,9 +118,9 @@ const char *Session::sdpEncoding(void)
 	case Audio::alawAudio:
 		return "PCMA/8000/1";
 	case Audio::pcm16Mono:
-		return "L16/11025/1";
+		return "L16/11025";
 	case Audio::pcm16Stereo:
-		return "L16/11025/2";
+		return "L16-2CH/11025";
 	case Audio::g721ADPCM:
 		return "G726-32/8000/1";
 	case Audio::g723_2bit:
@@ -113,29 +142,44 @@ const char *Session::sdpEncoding(void)
 
 void Session::setPeering(const char *enc)
 {
+	char map[65];
+
 	if(!enc)
 		return;
 
+	if(!strnicmp(enc, "g.", 2))
+		enc += 2;
+	else if(!strnicmp(enc, "g7", 2))
+		++enc;
+	else if(*enc == '.')
+		++enc;
+
 	if(!stricmp(enc, "gsm"))
 		enc = "a=rtpmap:3 GSM/8000/1";
-	else if(!stricmp(enc, "ulaw") || !stricmp(enc, "mulaw"))
+	else if(!stricmp(enc, "ulaw") || !stricmp(enc, "mulaw") || !stricmp(enc, "pcmu"))
 		enc = "a=rtpmap:0 PCMU/8000/1";
-	else if(!stricmp(enc, "alaw"))
+	else if(!stricmp(enc, "alaw") || !stricmp(enc, "pcma"))
 		enc = "a=rtpmap:8 PCMU/8000/1";
-	else if(!stricmp(enc, "adpcm"))
+	else if(!stricmp(enc, "adpcm") || !stricmp(enc, "721"))
 		enc = "a=rtpmap:97 G726-32/8000/1";
 	else if(!stricmp(enc, "stereo"))
 		enc = "a=rtpmap:98 L16/11025/2";
-	else if(!stricmp(enc, "g726-16"))
+	else if(!stricmp(enc, "726-16") || !stricmp(enc, "a16"))
 		enc = "a=rtpmap:94 G726-16/8000/1";
-	else if(!stricmp(enc, "g726-24"))
+	else if(!stricmp(enc, "726-32") || !stricmp(enc, "a32"))
+		enc = "a=rtpmap:97 G726-32/8000/1";
+	else if(!stricmp(enc, "726-24") || !stricmp(enc, "a24"))
 		enc = "a=rtpmap:95 G726-24/8000/1";
-	else if(!stricmp(enc, "g726-40"))
+	else if(!stricmp(enc, "726-40") || !stricmp(enc, "a40"))
 		enc = "a=rtpmap:96 G726-40/8000/1";
-	else if(!stricmp(enc, "g729"))
+	else if(!stricmp(enc, "729"))
 		enc = "a=rtpmap:18 G729/8000/1";
 	else
-		enc = getSymbol("session.sdp_encoding");
+	{
+		snprintf(map, sizeof(map), "a=rtpmap:%d %s",
+			sdpPayload(), sdpEncoding());
+		enc = map;
+	}
 
 	setConst("session.sdp_peering", enc);
 }
@@ -302,12 +346,14 @@ void Session::setEncoding(const char *encoding, timeout_t framing)
 
 	if(!stricmp(encoding, "stereo"))
 		info.encoding = Audio::pcm16Stereo;
-	else if(!stricmp(encoding, "g726-40"))
+	else if(!stricmp(encoding, "g726-40") || !stricmp(encoding, "a40"))
 		info.encoding = Audio::g723_5bit;
-	else if(!stricmp(encoding, "g726-24"))
+	else if(!stricmp(encoding, "g726-24") || !stricmp(encoding, "a24"))
 		info.encoding = Audio::g723_3bit;
-	else if(!stricmp(encoding, "g726-16"))
+	else if(!stricmp(encoding, "g726-16") || !stricmp(encoding, "a16"))
 		info.encoding = Audio::g723_2bit;
+	else if(!stricmp(encoding, "a32"))
+		info.encoding = Audio::g721ADPCM;
 	else
 		info.encoding = Audio::getEncoding(encoding);
 
@@ -1062,17 +1108,63 @@ bool Session::enterPickup(Event *event)
 bool Session::enterReconnect(Event *event)
 {
 	const char *sdp;
+	const char *enc;
 
 	switch(event->id)
 	{
 	case ENTER_RECONNECT:
 		sdp = getSymbol("session.sdp_reconnect");
 		if(!sdp || !*sdp)
+		{
+			reconnecting = false;
 			return false;
+		}
 
-		if(!stristr(sdp, event->reconnect.encoding))
+		enc = event->reconnect.encoding;
+		if(*enc == '.')
+			++enc;
+		else if(!stricmp(enc, "mulaw"))
+			++enc;
+		else if(!strnicmp(enc, "g.7", 3))
+			enc += 2;
+		else if(!strnicmp(enc, "g7", 2))
+			++enc;
+
+
+		if(event->reconnect.framing && event->reconnect.framing != info.framing)
+			goto test;
+
+		// no need for reconnect if we already are
+		if(stristr(sdpNames(), enc))
+		{
+			reconnecting = false;
 			return false;
+		}
 
+test:
+		if(!stricmp(enc, "adpcm") || !stricmp(enc, "721"))
+			if(stristr(sdp, "a32"))
+				goto recon;
+
+		if(!stricmp(enc, "adcpm") || !stricmp(enc, "a32"))
+			if(stristr(sdp, "721"))
+				goto recon;
+
+		if(!stricmp(enc, "pcmu"))
+			if(stristr(sdp, "ulaw"))
+				goto recon;
+
+		if(!stricmp(enc, "pcma"))
+			if(strstr(sdp, "alaw"))
+				goto recon;
+
+		if(!stristr(sdp, enc))
+		{
+			reconnecting = false;
+			return false;
+		}
+
+recon:
 		if(reconnecting)
 		{
 			reconnecting = false;
