@@ -454,14 +454,23 @@ bool Methods::scrRoute(void)
 	if(!cp)
 		cp = "digits";
 
+	setSymbol("script.error", "none");
+
 	while(NULL != (opt = getValue(NULL)))
 	{
 		snprintf(evt, sizeof(evt), "%s:%s", cp, opt);
 		if(digitEvent(evt))
+		{
+			snprintf(dtmf_digits, MAX_DTMF + 1, "%s", opt);			
 			return false;
+		}
 	}
+
+	snprintf(evt, sizeof(evt), "%s:invalid", cp);
+	if(scriptEvent(evt))
+		return false;
 	
-	error("no-digit-match");
+	error("route-invalid");
 	return true;
 }
 
@@ -474,6 +483,8 @@ bool Methods::scrSRoute(void)
 	if(!cp)
 		cp = "digits";
 
+	setSymbol("script.error", "none");
+
 	while(NULL != (opt = getValue(NULL)))
 	{
 		snprintf(evt, sizeof(evt), "%s:%s", cp, opt);
@@ -481,7 +492,7 @@ bool Methods::scrSRoute(void)
 			return false;
 	}
 	
-	error("no-string-match");
+	error("route-invalid");
 	return true;
 }
 	
